@@ -7,7 +7,7 @@ try:
     from tomli_w import dumps
 except ImportError:  # pragma: no cover
     # Let's try another API-compatible popular library as a last hope
-    from toml import dumps  # type: ignore
+    from toml import dumps  # type: ignore[import]
 
 from ..types import IntermediateRepr
 from . import plain_builtins
